@@ -29,6 +29,9 @@ class PercentageFocus(Focus):
     def evaluate_buy(
         self, symbol: str, news: List[News], current_price: float, candles: Dict[str, Candle], logger: Logger
     ) -> Tuple[bool, str]:
+        if not candles:
+            return False, "Not enough candle data."
+
         open_price: float = candles[list(candles.keys())[-1]].open
         diff: float = (current_price - open_price) / open_price * 100
 
