@@ -29,13 +29,3 @@ class State(Enum):
 
     def value(self) -> str:
         return self.name.lower()
-
-
-def main() -> None:
-    print(State.to_enum("active"))
-    print(State.to_enum("cancelled"))
-    print(State.ACTIVE.value())
-
-
-if __name__ == "__main__":
-    main()
